@@ -3,7 +3,8 @@ from nonebot.log import logger
 from nonebot.adapters.cqhttp import MessageSegment
 
 from .download import get_avatar, get_image, DownloadError
-from .functions import petpet, kiss, rub, play, rip, throw, crawl, support
+from .functions import square, to_image
+from .functions import petpet, kiss, rub, play, pat, rip, throw, crawl, support
 
 
 commands = {
@@ -23,6 +24,10 @@ commands = {
         'aliases': {'顶', '玩'},
         'func': play
     },
+    'pat': {
+        'aliases': {'拍'},
+        'func': pat
+    },
     'rip': {
         'aliases': {'撕'},
         'func': rip
@@ -49,8 +54,10 @@ async def make_image(type: str, self_id: str, user_id: str = '', img_url: str =
 
         if user_id:
             user_img = await get_avatar(user_id)
+            user_img = to_image(user_img)
         elif img_url:
             user_img = await get_image(img_url)
+            user_img = square(to_image(user_img))
         else:
             return None
 
@@ -58,6 +65,7 @@ async def make_image(type: str, self_id: str, user_id: str = '', img_url: str =
 
         if type in ['kiss', 'rub']:
             self_img = await get_avatar(self_id)
+            self_img = to_image(self_img)
             result = await func(self_img, user_img)
         else:
             result = await func(user_img)
